# frozen_string_literal: true

require 'cht-chaphql'
require 'cht_apitest_local_auth'
require 'cht_apitest_local_auth/service'

Dir[File.join(__dir__, '../lib/*', '*.rb')].sort.each { |file| require file }
Dir[File.join(__dir__, 'helpers/*.rb')].sort.each { |f| require f }

RSpec.configure do |c|
  c.include Chaphql
  c.include Chaphql::GraphQLHelpers
  c.include Chaphql::AnalyzerHelpers
  c.include Chaphql::StringManipulation
  c.include Chaphql::ServiceHelper
  c.include Chaphql::IntrospectConflict
  c.include ChtApitestLocalAuth
  c.include ChtApitestAuthCommon
  c.include Spaceborne
  include ChtApitestQueryEngineFlushing
  include QueryEngineFlushingHelpers
  c.filter_run_excluding(save_schema: true)
  c.filter_run_excluding(staging_env: true) unless ENV['TEST_ENV'] == 'staging'
  c.filter_run_excluding(not_via_proxy: true) if ENV['EKS_ENV'] == 'external'
  c.shared_context_metadata_behavior = :apply_to_host_groups
  c.before(:each) do |example|
    @test_tag = self
  end
  c.after(:suite) do
    puts Characterizer.check_results +
         Characterizer.test_missing_supported_data(
           IAnalyzer.new(nil).do_introspect(
             ChtApitestQueryEngineFlushing::QueryEngineFlushingService.new,
             LocalAuthService.new(via_public: %w{prod canary staging}.include?(getenv)))).join('')
  end
  c.example_status_persistence_file_path  = 'rspec_times.txt'
end

RSpec.shared_context 'request metadata', shared_context: :metadata do
  let(:via_public) { %w[prod canary staging].include?(getenv) }
  let(:service) { ChtApitestQueryEngineFlushing::QueryEngineFlushingService.new }
  let(:auth_service) { LocalAuthService.new(via_public: via_public) }
  let(:tokens) { login_api(ENV['API_KEY'], service: auth_service) }
  let(:headers) do
    apitest_headers(service: auth_service,
                    with_auth: true,
                    access_token: tokens[:access_token])
  end
  let(:dbg_headers) { headers.merge(use_curl: 'debug') }
  let(:get_new_tokens) do
    headers = apitest_headers(service: auth_service,
                              with_auth: true,
                              refresh: tokens[:refresh_token])
    dbg_headers = headers.merge(use_curl: 'debug')
  end
end

RSpec.configure do |c|
  c.include_context 'request metadata', include_shared: true
end
